#!/usr/bin/env python3

from typing import Optional

from stytch.core.models import ResponseBase, StytchSession


class ResetResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/password-session-reset)"""  # noqa

    user_id: str
    session: Optional[StytchSession]



# !!!
# WARNING: This file is autogenerated
# Only modify code within MANUAL() sections
# or your changes may be overwritten later!
# !!!

from typing import Any, AsyncGenerator, Dict, Generator, List, Optional, Union

import pydantic

from stytch.core.api_base import ApiBase
from stytch.core.http.client import AsyncClient, SyncClient
from stytch.core.models import Name, SearchQuery
from stytch.models.users import (
    CreateResponse,
    DeleteBiometricRegistrationResponse,
    DeleteCryptoWalletResponse,
    DeleteEmailResponse,
    DeleteOauthUserRegistrationResponse,
    DeletePasswordResponse,
    DeletePhoneNumberResponse,
    DeleteResponse,
    DeleteTotpResponse,
    DeleteWebauthnRegistrationResponse,
    GetPendingResponse,
    GetResponse,
    SearchResponse,
    UpdateResponse,
)


class Users:
    def __init__(
        self,
        api_base: ApiBase,
        sync_client: SyncClient,
        async_client: AsyncClient,
    ) -> None:
        self.api_base = api_base
        self.sync_client = sync_client
        self.async_client = async_client

    @property
    def sub_url(self) -> str:
        return "users"

    def create(
        self,
        email: Optional[str] = None,
        phone_number: Optional[str] = None,
        name: Optional[Union[Name, Dict[str, str]]] = None,
        create_user_as_pending: bool = False,
        attributes: Optional[Dict[str, str]] = None,
        trusted_metadata: Optional[Dict[str, Any]] = None,
        untrusted_metadata: Optional[Dict[str, Any]] = None,
    ) -> CreateResponse:
        """[Stytch docs](https://stytch.com/docs/api/create-user)

        Add a user to Stytch. A `user_id` is returned in the response that can then be used to perform other operations within Stytch. An `email` or a `phone_number` is required.
        """  # noqa

        payload: Dict[str, Any] = {
            "create_user_as_pending": create_user_as_pending,
        }

        if email is not None:
            payload["email"] = email
        if phone_number is not None:
            payload["phone_number"] = phone_number
        if name is not None:
            payload["name"] = (
                name.dict() if isinstance(name, pydantic.BaseModel) else name
            )
        if attributes is not None:
            payload["attributes"] = attributes
        if trusted_metadata is not None:
            payload["trusted_metadata"] = trusted_metadata
        if untrusted_metadata is not None:
            payload["untrusted_metadata"] = untrusted_metadata

        url = self.api_base.route_with_sub_url(self.sub_url, None)

        res = self.sync_client.post(url, json=payload)
        return CreateResponse.from_json(res.response.status_code, res.json)

    async def create_async(
        self,
        email: Optional[str] = None,
        phone_number: Optional[str] = None,
        name: Optional[Union[Name, Dict[str, str]]] = None,
        create_user_as_pending: bool = False,
        attributes: Optional[Dict[str, str]] = None,
        trusted_metadata: Optional[Dict[str, Any]] = None,
        untrusted_metadata: Optional[Dict[str, Any]] = None,
    ) -> CreateResponse:
        """[Stytch docs](https://stytch.com/docs/api/create-user)

        Add a user to Stytch. A `user_id` is returned in the response that can then be used to perform other operations within Stytch. An `email` or a `phone_number` is required.
        """  # noqa

        payload: Dict[str, Any] = {
            "create_user_as_pending": create_user_as_pending,
        }

        if email is not None:
            payload["email"] = email
        if phone_number is not None:
            payload["phone_number"] = phone_number
        if name is not None:
            payload["name"] = (
                name.dict() if isinstance(name, pydantic.BaseModel) else name
            )
        if attributes is not None:
            payload["attributes"] = attributes
        if trusted_metadata is not None:
            payload["trusted_metadata"] = trusted_metadata
        if untrusted_metadata is not None:
            payload["untrusted_metadata"] = untrusted_metadata

        url = self.api_base.route_with_sub_url(self.sub_url, None)

        res = await self.async_client.post(url, json=payload)
        return CreateResponse.from_json(res.response.status, res.json)

    def get(
        self,
        user_id: str,
    ) -> GetResponse:
        """[Stytch docs](https://stytch.com/docs/api/get-user)

        Fetch a given user to see what their various attributes are. All timestamps are formatted according to the RFC 3339 standard and are expressed in UTC, e.g. `2021-12-29T12:33:09Z`.
        """  # noqa

        payload: Dict[str, Any] = {
            "user_id": user_id,
        }

        url = self.api_base.route_with_sub_url(self.sub_url, user_id)

        res = self.sync_client.get(url, params=payload)
        return GetResponse.from_json(res.response.status_code, res.json)

    async def get_async(
        self,
        user_id: str,
    ) -> GetResponse:
        """[Stytch docs](https://stytch.com/docs/api/get-user)

        Fetch a given user to see what their various attributes are. All timestamps are formatted according to the RFC 3339 standard and are expressed in UTC, e.g. `2021-12-29T12:33:09Z`.
        """  # noqa

        payload: Dict[str, Any] = {
            "user_id": user_id,
        }

        url = self.api_base.route_with_sub_url(self.sub_url, user_id)

        res = await self.async_client.get(url, params=payload)
        return GetResponse.from_json(res.response.status, res.json)

    def get_pending(
        self,
        limit: Optional[int] = None,
        starting_after_id: Optional[str] = None,
    ) -> GetPendingResponse:
        """[Stytch docs](https://stytch.com/docs/api/get-pending-users)

        Fetch all users with a pending status. Users will show up here if they are added via the `invite_by_email` endpoint or via `login_or_create` where `create_as_pending = true` and have yet to create their account by clicking on the magic link in the email. All timestamps are formatted according to the RFC 3339 standard and are expressed in UTC, e.g. `2021-12-29T12:33:09Z`.
        """  # noqa

        payload: Dict[str, Any] = {}

        if limit is not None:
            payload["limit"] = limit
        if starting_after_id is not None:
            payload["starting_after_id"] = starting_after_id

        url = self.api_base.route_with_sub_url(self.sub_url, "pending")

        res = self.sync_client.get(url, params=payload)
        return GetPendingResponse.from_json(res.response.status_code, res.json)

    async def get_pending_async(
        self,
        limit: Optional[int] = None,
        starting_after_id: Optional[str] = None,
    ) -> GetPendingResponse:
        """[Stytch docs](https://stytch.com/docs/api/get-pending-users)

        Fetch all users with a pending status. Users will show up here if they are added via the `invite_by_email` endpoint or via `login_or_create` where `create_as_pending = true` and have yet to create their account by clicking on the magic link in the email. All timestamps are formatted according to the RFC 3339 standard and are expressed in UTC, e.g. `2021-12-29T12:33:09Z`.
        """  # noqa

        payload: Dict[str, Any] = {}

        if limit is not None:
            payload["limit"] = limit
        if starting_after_id is not None:
            payload["starting_after_id"] = starting_after_id

        url = self.api_base.route_with_sub_url(self.sub_url, "pending")

        res = await self.async_client.get(url, params=payload)
        return GetPendingResponse.from_json(res.response.status, res.json)

    def search(
        self,
        limit: Optional[int] = None,
        cursor: Optional[str] = None,
        query: Optional[Union[SearchQuery, Dict[str, Any]]] = None,
    ) -> SearchResponse:
        """[Stytch docs](https://stytch.com/docs/api/search-users)

        Search across your users at Stytch. This endpoint also allows you to return all of your users; simply send an empty body and no filtering will be applied.
        """  # noqa

        payload: Dict[str, Any] = {}

        if limit is not None:
            payload["limit"] = limit
        if cursor is not None:
            payload["cursor"] = cursor
        if query is not None:
            payload["query"] = (
                query.dict() if isinstance(query, pydantic.BaseModel) else query
            )

        url = self.api_base.route_with_sub_url(self.sub_url, "search")

        res = self.sync_client.post(url, json=payload)
        return SearchResponse.from_json(res.response.status_code, res.json)

    async def search_async(
        self,
        limit: Optional[int] = None,
        cursor: Optional[str] = None,
        query: Optional[Union[SearchQuery, Dict[str, Any]]] = None,
    ) -> SearchResponse:
        """[Stytch docs](https://stytch.com/docs/api/search-users)

        Search across your users at Stytch. This endpoint also allows you to return all of your users; simply send an empty body and no filtering will be applied.
        """  # noqa

        payload: Dict[str, Any] = {}

        if limit is not None:
            payload["limit"] = limit
        if cursor is not None:
            payload["cursor"] = cursor
        if query is not None:
            payload["query"] = (
                query.dict() if isinstance(query, pydantic.BaseModel) else query
            )

        url = self.api_base.route_with_sub_url(self.sub_url, "search")

        res = await self.async_client.post(url, json=payload)
        return SearchResponse.from_json(res.response.status, res.json)

    # MANUAL(search_all)
    def search_all(
        self,
        limit: Optional[int] = None,
        cursor: Optional[str] = None,
        query: Optional[Union[SearchQuery, Dict[str, Any]]] = None,
    ) -> Generator[SearchResponse, None, None]:
        # 1. Check if this method should be async or not
        # 2. Set the return type appropriately
        # 3. Fill out the method details
        # 4. Remember to write a test since this is manually generated
        while True:
            results = self.search(limit, cursor, query)
            yield results
            cursor = results.results_metadata.next_cursor
            if cursor is None:
                break

    async def search_all_async(
        self,
        limit: Optional[int] = None,
        cursor: Optional[str] = None,
        query: Optional[Union[SearchQuery, Dict[str, Any]]] = None,
    ) -> AsyncGenerator[SearchResponse, None]:
        # 1. Check if this method should be async or not
        # 2. Set the return type appropriately
        # 3. Fill out the method details
        # 4. Remember to write a test since this is manually generated
        while True:
            results = await self.search_async(limit, cursor, query)
            yield results
            cursor = results.results_metadata.next_cursor
            if cursor is None:
                break

    # ENDMANUAL(search_all)

    def delete(
        self,
        user_id: str,
    ) -> DeleteResponse:
        """[Stytch docs](https://stytch.com/docs/api/delete-user)

        Remove a user from Stytch.
        """  # noqa

        url = self.api_base.route_with_sub_url(self.sub_url, user_id)

        res = self.sync_client.delete(url)
        return DeleteResponse.from_json(res.response.status_code, res.json)

    async def delete_async(
        self,
        user_id: str,
    ) -> DeleteResponse:
        """[Stytch docs](https://stytch.com/docs/api/delete-user)

        Remove a user from Stytch.
        """  # noqa

        url = self.api_base.route_with_sub_url(self.sub_url, user_id)

        res = await self.async_client.delete(url)
        return DeleteResponse.from_json(res.response.status, res.json)

    def update(
        self,
        user_id: str,
        emails: Optional[List[str]] = None,
        phone_numbers: Optional[List[str]] = None,
        crypto_wallets: Optional[List[str]] = None,
        name: Optional[Union[Name, Dict[str, str]]] = None,
        attributes: Optional[Dict[str, str]] = None,
        trusted_metadata: Optional[Dict[str, Any]] = None,
        untrusted_metadata: Optional[Dict[str, Any]] = None,
    ) -> UpdateResponse:
        """[Stytch docs](https://stytch.com/docs/api/update-user)

        Update a user's name or attributes.

        **Note:** In order to add a new email address or phone number to an existing User object, pass the new email address or phone number into the respective `/send` endpoint for the authentication method of your choice. If you specify the existing user's Stytch `user_id` while calling the `/send` endpoint, the new email address or phone number will be added to the existing User object upon successful authentication. We require this process to guard against an account takeover vulnerability.
        """  # noqa

        payload: Dict[str, Any] = {
            "user_id": user_id,
        }

        if emails is not None:
            payload["emails"] = emails
        if phone_numbers is not None:
            payload["phone_numbers"] = phone_numbers
        if crypto_wallets is not None:
            payload["crypto_wallets"] = crypto_wallets
        if name is not None:
            payload["name"] = (
                name.dict() if isinstance(name, pydantic.BaseModel) else name
            )
        if attributes is not None:
            payload["attributes"] = attributes
        if trusted_metadata is not None:
            payload["trusted_metadata"] = trusted_metadata
        if untrusted_metadata is not None:
            payload["untrusted_metadata"] = untrusted_metadata

        url = self.api_base.route_with_sub_url(self.sub_url, user_id)

        res = self.sync_client.put(url, json=payload)
        return UpdateResponse.from_json(res.response.status_code, res.json)

    async def update_async(
        self,
        user_id: str,
        emails: Optional[List[str]] = None,
        phone_numbers: Optional[List[str]] = None,
        crypto_wallets: Optional[List[str]] = None,
        name: Optional[Union[Name, Dict[str, str]]] = None,
        attributes: Optional[Dict[str, str]] = None,
        trusted_metadata: Optional[Dict[str, Any]] = None,
        untrusted_metadata: Optional[Dict[str, Any]] = None,
    ) -> UpdateResponse:
        """[Stytch docs](https://stytch.com/docs/api/update-user)

        Update a user's name or attributes.

        **Note:** In order to add a new email address or phone number to an existing User object, pass the new email address or phone number into the respective `/send` endpoint for the authentication method of your choice. If you specify the existing user's Stytch `user_id` while calling the `/send` endpoint, the new email address or phone number will be added to the existing User object upon successful authentication. We require this process to guard against an account takeover vulnerability.
        """  # noqa

        payload: Dict[str, Any] = {
            "user_id": user_id,
        }

        if emails is not None:
            payload["emails"] = emails
        if phone_numbers is not None:
            payload["phone_numbers"] = phone_numbers
        if crypto_wallets is not None:
            payload["crypto_wallets"] = crypto_wallets
        if name is not None:
            payload["name"] = (
                name.dict() if isinstance(name, pydantic.BaseModel) else name
            )
        if attributes is not None:
            payload["attributes"] = attributes
        if trusted_metadata is not None:
            payload["trusted_metadata"] = trusted_metadata
        if untrusted_metadata is not None:
            payload["untrusted_metadata"] = untrusted_metadata

        url = self.api_base.route_with_sub_url(self.sub_url, user_id)

        res = await self.async_client.put(url, json=payload)
        return UpdateResponse.from_json(res.response.status, res.json)

    def delete_email(
        self,
        email_id: str,
    ) -> DeleteEmailResponse:
        """[Stytch docs](https://stytch.com/docs/api/delete-user-email)

        Remove an email from a given user.
        """  # noqa

        url = self.api_base.route_with_sub_url(self.sub_url, f"emails/{email_id}")

        res = self.sync_client.delete(url)
        return DeleteEmailResponse.from_json(res.response.status_code, res.json)

    async def delete_email_async(
        self,
        email_id: str,
    ) -> DeleteEmailResponse:
        """[Stytch docs](https://stytch.com/docs/api/delete-user-email)

        Remove an email from a given user.
        """  # noqa

        url = self.api_base.route_with_sub_url(self.sub_url, f"emails/{email_id}")

        res = await self.async_client.delete(url)
        return DeleteEmailResponse.from_json(res.response.status, res.json)

    def delete_phone_number(
        self,
        phone_id: str,
    ) -> DeletePhoneNumberResponse:
        """[Stytch docs](https://stytch.com/docs/api/delete-user-phone-number)

        Remove a phone number from a given user.
        """  # noqa

        url = self.api_base.route_with_sub_url(
            self.sub_url, f"phone_numbers/{phone_id}"
        )

        res = self.sync_client.delete(url)
        return DeletePhoneNumberResponse.from_json(res.response.status_code, res.json)

    async def delete_phone_number_async(
        self,
        phone_id: str,
    ) -> DeletePhoneNumberResponse:
        """[Stytch docs](https://stytch.com/docs/api/delete-user-phone-number)

        Remove a phone number from a given user.
        """  # noqa

        url = self.api_base.route_with_sub_url(
            self.sub_url, f"phone_numbers/{phone_id}"
        )

        res = await self.async_client.delete(url)
        return DeletePhoneNumberResponse.from_json(res.response.status, res.json)

    def delete_webauthn_registration(
        self,
        webauthn_registration_id: str,
    ) -> DeleteWebauthnRegistrationResponse:
        """[Stytch docs](https://stytch.com/docs/api/delete-user-webauthn-registration)

        Delete a previously created WebAuthn registration.
        """  # noqa

        url = self.api_base.route_with_sub_url(
            self.sub_url, f"webauthn_registrations/{webauthn_registration_id}"
        )

        res = self.sync_client.delete(url)
        return DeleteWebauthnRegistrationResponse.from_json(
            res.response.status_code, res.json
        )

    async def delete_webauthn_registration_async(
        self,
        webauthn_registration_id: str,
    ) -> DeleteWebauthnRegistrationResponse:
        """[Stytch docs](https://stytch.com/docs/api/delete-user-webauthn-registration)

        Delete a previously created WebAuthn registration.
        """  # noqa

        url = self.api_base.route_with_sub_url(
            self.sub_url, f"webauthn_registrations/{webauthn_registration_id}"
        )

        res = await self.async_client.delete(url)
        return DeleteWebauthnRegistrationResponse.from_json(
            res.response.status, res.json
        )

    def delete_totp(
        self,
        totp_id: str,
    ) -> DeleteTotpResponse:
        """[Stytch docs](https://stytch.com/docs/api/delete-user-totp)

        Delete a previously created TOTP instance.
        """  # noqa

        url = self.api_base.route_with_sub_url(self.sub_url, f"totps/{totp_id}")

        res = self.sync_client.delete(url)
        return DeleteTotpResponse.from_json(res.response.status_code, res.json)

    async def delete_totp_async(
        self,
        totp_id: str,
    ) -> DeleteTotpResponse:
        """[Stytch docs](https://stytch.com/docs/api/delete-user-totp)

        Delete a previously created TOTP instance.
        """  # noqa

        url = self.api_base.route_with_sub_url(self.sub_url, f"totps/{totp_id}")

        res = await self.async_client.delete(url)
        return DeleteTotpResponse.from_json(res.response.status, res.json)

    def delete_crypto_wallet(
        self,
        crypto_wallet_id: str,
    ) -> DeleteCryptoWalletResponse:
        """[Stytch docs](https://stytch.com/docs/api/delete-user-crypto-wallet)

        Delete a crypto wallet.
        """  # noqa

        url = self.api_base.route_with_sub_url(
            self.sub_url, f"crypto_wallets/{crypto_wallet_id}"
        )

        res = self.sync_client.delete(url)
        return DeleteCryptoWalletResponse.from_json(res.response.status_code, res.json)

    async def delete_crypto_wallet_async(
        self,
        crypto_wallet_id: str,
    ) -> DeleteCryptoWalletResponse:
        """[Stytch docs](https://stytch.com/docs/api/delete-user-crypto-wallet)

        Delete a crypto wallet.
        """  # noqa

        url = self.api_base.route_with_sub_url(
            self.sub_url, f"crypto_wallets/{crypto_wallet_id}"
        )

        res = await self.async_client.delete(url)
        return DeleteCryptoWalletResponse.from_json(res.response.status, res.json)

    def delete_password(
        self,
        password_id: str,
    ) -> DeletePasswordResponse:
        """[Stytch docs](https://stytch.com/docs/api/delete-user-password)

        Delete a password.
        """  # noqa

        url = self.api_base.route_with_sub_url(self.sub_url, f"passwords/{password_id}")

        res = self.sync_client.delete(url)
        return DeletePasswordResponse.from_json(res.response.status_code, res.json)

    async def delete_password_async(
        self,
        password_id: str,
    ) -> DeletePasswordResponse:
        """[Stytch docs](https://stytch.com/docs/api/delete-user-password)

        Delete a password.
        """  # noqa

        url = self.api_base.route_with_sub_url(self.sub_url, f"passwords/{password_id}")

        res = await self.async_client.delete(url)
        return DeletePasswordResponse.from_json(res.response.status, res.json)

    def delete_biometric_registration(
        self,
        biometric_registration_id: str,
    ) -> DeleteBiometricRegistrationResponse:
        """[Stytch docs](https://stytch.com/docs/api/delete-user-biometric-registration)

        Delete a previously created biometric registration.
        """  # noqa

        url = self.api_base.route_with_sub_url(
            self.sub_url, f"biometric_registrations/{biometric_registration_id}"
        )

        res = self.sync_client.delete(url)
        return DeleteBiometricRegistrationResponse.from_json(
            res.response.status_code, res.json
        )

    async def delete_biometric_registration_async(
        self,
        biometric_registration_id: str,
    ) -> DeleteBiometricRegistrationResponse:
        """[Stytch docs](https://stytch.com/docs/api/delete-user-biometric-registration)

        Delete a previously created biometric registration.
        """  # noqa

        url = self.api_base.route_with_sub_url(
            self.sub_url, f"biometric_registrations/{biometric_registration_id}"
        )

        res = await self.async_client.delete(url)
        return DeleteBiometricRegistrationResponse.from_json(
            res.response.status, res.json
        )

    def delete_oauth_user_registration(
        self,
        oauth_user_registration_id: str,
    ) -> DeleteOauthUserRegistrationResponse:
        """[Stytch docs](https://stytch.com/docs/api/delete-user-oauth-registration)

        Delete an oauth user registration.
        """  # noqa

        url = self.api_base.route_with_sub_url(
            self.sub_url, f"oauth/{oauth_user_registration_id}"
        )

        res = self.sync_client.delete(url)
        return DeleteOauthUserRegistrationResponse.from_json(
            res.response.status_code, res.json
        )

    async def delete_oauth_user_registration_async(
        self,
        oauth_user_registration_id: str,
    ) -> DeleteOauthUserRegistrationResponse:
        """[Stytch docs](https://stytch.com/docs/api/delete-user-oauth-registration)

        Delete an oauth user registration.
        """  # noqa

        url = self.api_base.route_with_sub_url(
            self.sub_url, f"oauth/{oauth_user_registration_id}"
        )

        res = await self.async_client.delete(url)
        return DeleteOauthUserRegistrationResponse.from_json(
            res.response.status, res.json
        )



#!/usr/bin/env python3

from typing import List

from stytch.core.models import (
    CryptoWallet,
    Email,
    PhoneNumber,
    ResponseBase,
    SearchResultsMetadata,
    User,
)


class CreateResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/create-user)"""  # noqa

    user_id: str
    user: User
    email_id: str
    phone_id: str
    status: str


class GetResponse(ResponseBase, User):
    """[Stytch docs](https://stytch.com/docs/api/get-user)"""  # noqa

    user_id: str


class GetPendingResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/get-pending-users)"""  # noqa

    users: List[User]
    has_more: bool
    next_starting_after_id: str
    total: int


class SearchResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/search-users)"""  # noqa

    results: List[User]
    results_metadata: SearchResultsMetadata


class DeleteResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/delete-user)"""  # noqa

    user_id: str


class UpdateResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/update-user)"""  # noqa

    user_id: str
    user: User
    emails: List[Email]
    phone_numbers: List[PhoneNumber]
    crypto_wallets: List[CryptoWallet]


class DeleteEmailResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/delete-user-email)"""  # noqa

    user_id: str
    user: User


class DeletePhoneNumberResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/delete-user-phone-number)"""  # noqa

    user_id: str
    user: User


class DeleteWebauthnRegistrationResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/delete-user-webauthn-registration)"""  # noqa

    user_id: str
    user: User


class DeleteTotpResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/delete-user-totp)"""  # noqa

    user_id: str
    user: User


class DeleteCryptoWalletResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/delete-user-crypto-wallet)"""  # noqa

    user_id: str
    user: User


class DeletePasswordResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/delete-user-password)"""  # noqa

    user_id: str
    user: User


class DeleteBiometricRegistrationResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/delete-user-biometric-registration)"""  # noqa

    user_id: str
    user: User


class DeleteOauthUserRegistrationResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/delete-user-oauth-registration)"""  # noqa

    user_id: str
    user: User



# !!!
# WARNING: This file is autogenerated
# Only modify code within MANUAL() sections
# or your changes may be overwritten later!
# !!!

from typing import Any, Dict, Optional

from stytch.api.otp_email import Email
from stytch.api.otp_sms import SMS
from stytch.api.otp_whatsapp import Whatsapp
from stytch.core.api_base import ApiBase
from stytch.core.http.client import AsyncClient, SyncClient
from stytch.models.otp import AuthenticateResponse


class OTP:
    def __init__(
        self,
        api_base: ApiBase,
        sync_client: SyncClient,
        async_client: AsyncClient,
    ) -> None:
        self.api_base = api_base
        self.sync_client = sync_client
        self.async_client = async_client
        self.email = Email(api_base, sync_client, async_client)
        self.sms = SMS(api_base, sync_client, async_client)
        self.whatsapp = Whatsapp(api_base, sync_client, async_client)

    @property
    def sub_url(self) -> str:
        return "otps"

    def authenticate(
        self,
        method_id: str,
        code: str,
        attributes: Optional[Dict[str, str]] = None,
        options: Optional[Dict[str, str]] = None,
        session_token: Optional[str] = None,
        session_jwt: Optional[str] = None,
        session_duration_minutes: Optional[int] = None,
        session_custom_claims: Optional[Dict[str, Any]] = None,
    ) -> AuthenticateResponse:
        """[Stytch docs](https://stytch.com/docs/api/authenticate-otp)

        Authenticate a user given a method ID and a code. This endpoint verifies that the code is valid, hasn't expired or been previously used, and any optional security settings such as IP match or user agent match are satisfied. A given `method_id` may only have a single active OTP code at any given time, if a user requests another OTP code before the first one has expired, the first one will be invalidated.
        """  # noqa

        payload: Dict[str, Any] = {
            "method_id": method_id,
            "code": code,
        }

        if attributes is not None:
            payload["attributes"] = attributes
        if options is not None:
            payload["options"] = options
        if session_token is not None:
            payload["session_token"] = session_token
        if session_jwt is not None:
            payload["session_jwt"] = session_jwt
        if session_duration_minutes is not None:
            payload["session_duration_minutes"] = session_duration_minutes
        if session_custom_claims is not None:
            payload["session_custom_claims"] = session_custom_claims

        url = self.api_base.route_with_sub_url(self.sub_url, "authenticate")

        res = self.sync_client.post(url, json=payload)
        return AuthenticateResponse.from_json(res.response.status_code, res.json)

    async def authenticate_async(
        self,
        method_id: str,
        code: str,
        attributes: Optional[Dict[str, str]] = None,
        options: Optional[Dict[str, str]] = None,
        session_token: Optional[str] = None,
        session_jwt: Optional[str] = None,
        session_duration_minutes: Optional[int] = None,
        session_custom_claims: Optional[Dict[str, Any]] = None,
    ) -> AuthenticateResponse:
        """[Stytch docs](https://stytch.com/docs/api/authenticate-otp)

        Authenticate a user given a method ID and a code. This endpoint verifies that the code is valid, hasn't expired or been previously used, and any optional security settings such as IP match or user agent match are satisfied. A given `method_id` may only have a single active OTP code at any given time, if a user requests another OTP code before the first one has expired, the first one will be invalidated.
        """  # noqa

        payload: Dict[str, Any] = {
            "method_id": method_id,
            "code": code,
        }

        if attributes is not None:
            payload["attributes"] = attributes
        if options is not None:
            payload["options"] = options
        if session_token is not None:
            payload["session_token"] = session_token
        if session_jwt is not None:
            payload["session_jwt"] = session_jwt
        if session_duration_minutes is not None:
            payload["session_duration_minutes"] = session_duration_minutes
        if session_custom_claims is not None:
            payload["session_custom_claims"] = session_custom_claims

        url = self.api_base.route_with_sub_url(self.sub_url, "authenticate")

        res = await self.async_client.post(url, json=payload)
        return AuthenticateResponse.from_json(res.response.status, res.json)



# !!!
# WARNING: This file is autogenerated
# Only modify code within MANUAL() sections
# or your changes may be overwritten later!
# !!!

from typing import Any, Dict, Optional

from stytch.core.api_base import ApiBase
from stytch.core.http.client import AsyncClient, SyncClient
from stytch.models.passwords_email import ResetResponse, ResetStartResponse


class Email:
    def __init__(
        self,
        api_base: ApiBase,
        sync_client: SyncClient,
        async_client: AsyncClient,
    ) -> None:
        self.api_base = api_base
        self.sync_client = sync_client
        self.async_client = async_client

    @property
    def sub_url(self) -> str:
        return "passwords/email"

    def reset_start(
        self,
        email: str,
        login_redirect_url: Optional[str] = None,
        reset_password_redirect_url: Optional[str] = None,
        reset_password_expiration_minutes: Optional[int] = None,
        attributes: Optional[Dict[str, str]] = None,
        code_challenge: Optional[str] = None,
        locale: Optional[str] = None,
        reset_password_template_id: Optional[str] = None,
    ) -> ResetStartResponse:
        """[Stytch docs](https://stytch.com/docs/api/password-email-reset-start)

        Initiates a password reset for the email address provided. This will trigger an email to be sent to the address, containing a magic link that will allow them to set a new password and authenticate.
        """  # noqa

        payload: Dict[str, Any] = {
            "email": email,
        }

        if login_redirect_url is not None:
            payload["login_redirect_url"] = login_redirect_url
        if reset_password_redirect_url is not None:
            payload["reset_password_redirect_url"] = reset_password_redirect_url
        if reset_password_expiration_minutes is not None:
            payload[
                "reset_password_expiration_minutes"
            ] = reset_password_expiration_minutes
        if attributes is not None:
            payload["attributes"] = attributes
        if code_challenge is not None:
            payload["code_challenge"] = code_challenge
        if locale is not None:
            payload["locale"] = locale
        if reset_password_template_id is not None:
            payload["reset_password_template_id"] = reset_password_template_id

        url = self.api_base.route_with_sub_url(self.sub_url, "reset/start")

        res = self.sync_client.post(url, json=payload)
        return ResetStartResponse.from_json(res.response.status_code, res.json)

    async def reset_start_async(
        self,
        email: str,
        login_redirect_url: Optional[str] = None,
        reset_password_redirect_url: Optional[str] = None,
        reset_password_expiration_minutes: Optional[int] = None,
        attributes: Optional[Dict[str, str]] = None,
        code_challenge: Optional[str] = None,
        locale: Optional[str] = None,
        reset_password_template_id: Optional[str] = None,
    ) -> ResetStartResponse:
        """[Stytch docs](https://stytch.com/docs/api/password-email-reset-start)

        Initiates a password reset for the email address provided. This will trigger an email to be sent to the address, containing a magic link that will allow them to set a new password and authenticate.
        """  # noqa

        payload: Dict[str, Any] = {
            "email": email,
        }

        if login_redirect_url is not None:
            payload["login_redirect_url"] = login_redirect_url
        if reset_password_redirect_url is not None:
            payload["reset_password_redirect_url"] = reset_password_redirect_url
        if reset_password_expiration_minutes is not None:
            payload[
                "reset_password_expiration_minutes"
            ] = reset_password_expiration_minutes
        if attributes is not None:
            payload["attributes"] = attributes
        if code_challenge is not None:
            payload["code_challenge"] = code_challenge
        if locale is not None:
            payload["locale"] = locale
        if reset_password_template_id is not None:
            payload["reset_password_template_id"] = reset_password_template_id

        url = self.api_base.route_with_sub_url(self.sub_url, "reset/start")

        res = await self.async_client.post(url, json=payload)
        return ResetStartResponse.from_json(res.response.status, res.json)

    def reset(
        self,
        token: str,
        password: str,
        session_token: Optional[str] = None,
        session_jwt: Optional[str] = None,
        session_duration_minutes: Optional[int] = None,
        session_custom_claims: Optional[Dict[str, Any]] = None,
        attributes: Optional[Dict[str, str]] = None,
        options: Optional[Dict[str, str]] = None,
        code_verifier: Optional[str] = None,
    ) -> ResetResponse:
        """[Stytch docs](https://stytch.com/docs/api/password-email-reset)

        Reset the user’s password and authenticate them. This endpoint checks that the magic link `token` is valid, hasn’t expired, or already been used – and can optionally require additional security settings, such as the IP address and user agent matching the initial reset request.

        The provided password needs to meet our password strength requirements, which can be checked in advance with the password strength endpoint. If the token and password are accepted, the password is securely stored for future authentication and the user is authenticated.
        """  # noqa

        payload: Dict[str, Any] = {
            "token": token,
            "password": password,
        }

        if session_token is not None:
            payload["session_token"] = session_token
        if session_jwt is not None:
            payload["session_jwt"] = session_jwt
        if session_duration_minutes is not None:
            payload["session_duration_minutes"] = session_duration_minutes
        if session_custom_claims is not None:
            payload["session_custom_claims"] = session_custom_claims
        if attributes is not None:
            payload["attributes"] = attributes
        if options is not None:
            payload["options"] = options
        if code_verifier is not None:
            payload["code_verifier"] = code_verifier

        url = self.api_base.route_with_sub_url(self.sub_url, "reset")

        res = self.sync_client.post(url, json=payload)
        return ResetResponse.from_json(res.response.status_code, res.json)

    async def reset_async(
        self,
        token: str,
        password: str,
        session_token: Optional[str] = None,
        session_jwt: Optional[str] = None,
        session_duration_minutes: Optional[int] = None,
        session_custom_claims: Optional[Dict[str, Any]] = None,
        attributes: Optional[Dict[str, str]] = None,
        options: Optional[Dict[str, str]] = None,
        code_verifier: Optional[str] = None,
    ) -> ResetResponse:
        """[Stytch docs](https://stytch.com/docs/api/password-email-reset)

        Reset the user’s password and authenticate them. This endpoint checks that the magic link `token` is valid, hasn’t expired, or already been used – and can optionally require additional security settings, such as the IP address and user agent matching the initial reset request.

        The provided password needs to meet our password strength requirements, which can be checked in advance with the password strength endpoint. If the token and password are accepted, the password is securely stored for future authentication and the user is authenticated.
        """  # noqa

        payload: Dict[str, Any] = {
            "token": token,
            "password": password,
        }

        if session_token is not None:
            payload["session_token"] = session_token
        if session_jwt is not None:
            payload["session_jwt"] = session_jwt
        if session_duration_minutes is not None:
            payload["session_duration_minutes"] = session_duration_minutes
        if session_custom_claims is not None:
            payload["session_custom_claims"] = session_custom_claims
        if attributes is not None:
            payload["attributes"] = attributes
        if options is not None:
            payload["options"] = options
        if code_verifier is not None:
            payload["code_verifier"] = code_verifier

        url = self.api_base.route_with_sub_url(self.sub_url, "reset")

        res = await self.async_client.post(url, json=payload)
        return ResetResponse.from_json(res.response.status, res.json)



#!/usr/bin/env python3

from typing import Any, Dict, Optional

from stytch.core.models import OAuthSession, ResponseBase, User


class AuthenticateResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/oauth-authenticate)

    Response fields beyond those defined in `ResponseBase`:

    - `user_id`: Globally unique UUID that identifies a specific user in the Stytch API. The `user_id` critical to perform operations on a user in our API, like Get user, Delete user, etc, so be sure to preserve this value.

    - `user`: The `user` object affected by this API call. See the [Get user endpoint](https://stytch.com/docs/api/get-user) for complete response field detail.

    - `oauth_user_registration_id`: Globally unique UUID that identifies singluar registration of a user with an OAuth identity provider in the Stytch API.

    - `provider_subject`: The `provider_subject` field is the unique identifier used to identify the user within a given OAuth provider. Also commonly called the "sub" or "Subject field" in OAuth protocols.

    - `provider_type`: The `provider_type` field denotes the OAuth identity provider that the user has authenticated with, e.g. Google, Facebook, GitHub etc.

    - `provider_values`: The `provider_values` object lists relevant identifiers, values, and scopes for a given OAuth provider. For example this object will include a provider's `access_token` that you can use to access the provider's API for a given user.

      Note that these values will vary based on the OAuth provider in question, e.g. `id_token` is only returned by Microsoft.

    - `reset_sessions`: Indicates if all other of this user's sessions need to be reset. You should check this field if you aren't using Stytch's Session product. If you are using Stytch's Session product, we revoke the user's other sessions for you.

    - `session`: If you initiate a session, by including `session_duration_minutes` in your authenticate call, you'll receive a full session object in the response.

      See [GET sessions](https://stytch.com/docs/api/session-get) for complete response fields.

    - `session_token`: A secret token for a given Stytch session. Read more about `session_token` in our [session management guide](https://stytch.com/docs/sessions#using-sessions).

    - `session_jwt`: The JSON Web Token (JWT) for a given Stytch session. Read more about JWTs in our [session management guide](https://stytch.com/docs/sessions#using-sessions).
    """  # noqa

    user_id: str
    user: Optional[User]
    oauth_user_registration_id: str
    provider_subject: str
    provider_type: str
    provider_values: Optional[Dict[str, Any]]
    reset_sessions: bool
    session: Optional[OAuthSession]
    session_jwt: str
    session_token: str


class AttachResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/oauth-overview)"""  # noqa

    oauth_attach_token: str



#!/usr/bin/env python3


from stytch.core.models import ResponseBase


class SendResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/send-otp-by-sms)"""  # noqa

    user_id: str
    phone_id: str


class LoginOrCreateResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/log-in-or-create-user-by-sms)"""  # noqa

    user_id: str
    phone_id: str
    user_created: bool



#!/usr/bin/env python3

import warnings

from stytch.api.crypto_wallets import CryptoWallets
from stytch.api.magic_links import MagicLinks
from stytch.api.oauth import OAuth
from stytch.api.otp import OTP
from stytch.api.passwords import Passwords
from stytch.api.sessions import Sessions
from stytch.api.totps import TOTPs
from stytch.api.users import Users
from stytch.api.webauthn import WebAuthn
from stytch.core.api_base import ApiBase
from stytch.core.http.client import AsyncClient, SyncClient


class Client:
    """
    Stytch API Python client.

    Learn more at https://stytch.com/docs
    """

    def __init__(
        self,
        project_id: str,
        secret: str,
        environment: str,
        suppress_warnings: bool = False,
    ):
        base_url = self._env_url(environment, suppress_warnings)
        api_base = ApiBase(base_url)
        sync_client = SyncClient(project_id, secret)
        async_client = AsyncClient(project_id, secret)

        self.users = Users(api_base, sync_client, async_client)
        self.magic_links = MagicLinks(api_base, sync_client, async_client)
        self.oauth = OAuth(api_base, sync_client, async_client)
        self.otps = OTP(api_base, sync_client, async_client)
        self.sessions = Sessions(api_base, sync_client, async_client)
        self.webauthn = WebAuthn(api_base, sync_client, async_client)
        self.totps = TOTPs(api_base, sync_client, async_client)
        self.crypto_wallets = CryptoWallets(api_base, sync_client, async_client)
        self.passwords = Passwords(api_base, sync_client, async_client)

    @classmethod
    def _env_url(cls, env: str, suppress_warnings: bool = False) -> str:
        """Resolve the base URL for the Stytch API environment."""

        # Supported production environments
        if env == "test":
            if not suppress_warnings:
                warnings.warn("Test version of Stytch not intended for production use")
            return "https://test.stytch.com/v1/"
        elif env == "live":
            return "https://api.stytch.com/v1/"

        return env



#!/usr/bin/env python3

from typing import List, Optional

from stytch.core.models import (
    ResponseBase,
    StytchSession,
    TOTPInstanceWithRecoveryCodes,
    User,
)


class CreateResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/totp-create)"""  # noqa

    secret: str
    totp_id: str
    qr_code: str
    recovery_codes: List[str]
    user_id: str
    user: Optional[User]


class AuthenticateResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/totp-authenticate)"""  # noqa

    user_id: str
    user: User
    totp_id: str
    session_jwt: str
    session_token: str
    session: Optional[StytchSession]


class RecoveryCodesResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/totp-get-recovery-codes)"""  # noqa

    user_id: str
    totps: List[TOTPInstanceWithRecoveryCodes]


class RecoverResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/totp-recover)"""  # noqa

    user_id: str
    user: User
    totp_id: str
    session_jwt: str
    session_token: str
    session: Optional[StytchSession]



#!/usr/bin/env python3

from typing import Any, Dict, List, Optional

from stytch.core.models import ResponseBase, StytchSession, User


class GetResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/session-get)"""  # noqa

    sessions: List[StytchSession]


class AuthenticateResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/session-auth)

    NOTE: The response object should always have the user field set (ie, it will not be None), but due to backwards
    compatibility with the `sessions.authenticate_jwt` method, the AuthenticateResponse marks it as Optional. The caller
    should always check since the field is Optional, but the intention is that it will _not_ be None.
    """  # noqa

    session: StytchSession
    session_jwt: str
    session_token: str
    user: Optional[User]


class RevokeResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/session-revoke)"""  # noqa


class JwksResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/jwks-get)"""  # noqa

    keys: List[Dict[str, Any]]



# !!!
# WARNING: This file is autogenerated
# Only modify code within MANUAL() sections
# or your changes may be overwritten later!
# !!!

from typing import Any, Dict, Optional

from stytch.core.api_base import ApiBase
from stytch.core.http.client import AsyncClient, SyncClient
from stytch.models.totps import (
    AuthenticateResponse,
    CreateResponse,
    RecoverResponse,
    RecoveryCodesResponse,
)


class TOTPs:
    def __init__(
        self,
        api_base: ApiBase,
        sync_client: SyncClient,
        async_client: AsyncClient,
    ) -> None:
        self.api_base = api_base
        self.sync_client = sync_client
        self.async_client = async_client

    @property
    def sub_url(self) -> str:
        return "totps"

    def create(
        self,
        user_id: str,
        expiration_minutes: Optional[int] = None,
    ) -> CreateResponse:
        """[Stytch docs](https://stytch.com/docs/api/totp-create)

        Create a new TOTP instance for a user. The user can use the authenticator application of their choice to scan the QR code or enter the secret.
        """  # noqa

        payload: Dict[str, Any] = {
            "user_id": user_id,
        }

        if expiration_minutes is not None:
            payload["expiration_minutes"] = expiration_minutes

        url = self.api_base.route_with_sub_url(self.sub_url, None)

        res = self.sync_client.post(url, json=payload)
        return CreateResponse.from_json(res.response.status_code, res.json)

    async def create_async(
        self,
        user_id: str,
        expiration_minutes: Optional[int] = None,
    ) -> CreateResponse:
        """[Stytch docs](https://stytch.com/docs/api/totp-create)

        Create a new TOTP instance for a user. The user can use the authenticator application of their choice to scan the QR code or enter the secret.
        """  # noqa

        payload: Dict[str, Any] = {
            "user_id": user_id,
        }

        if expiration_minutes is not None:
            payload["expiration_minutes"] = expiration_minutes

        url = self.api_base.route_with_sub_url(self.sub_url, None)

        res = await self.async_client.post(url, json=payload)
        return CreateResponse.from_json(res.response.status, res.json)

    def authenticate(
        self,
        user_id: str,
        totp_code: str,
        session_token: Optional[str] = None,
        session_jwt: Optional[str] = None,
        session_duration_minutes: Optional[int] = None,
        session_custom_claims: Optional[Dict[str, Any]] = None,
    ) -> AuthenticateResponse:
        """[Stytch docs](https://stytch.com/docs/api/totp-authenticate)

        Authenticate a TOTP code entered by a user.
        """  # noqa

        payload: Dict[str, Any] = {
            "user_id": user_id,
            "totp_code": totp_code,
        }

        if session_token is not None:
            payload["session_token"] = session_token
        if session_jwt is not None:
            payload["session_jwt"] = session_jwt
        if session_duration_minutes is not None:
            payload["session_duration_minutes"] = session_duration_minutes
        if session_custom_claims is not None:
            payload["session_custom_claims"] = session_custom_claims

        url = self.api_base.route_with_sub_url(self.sub_url, "authenticate")

        res = self.sync_client.post(url, json=payload)
        return AuthenticateResponse.from_json(res.response.status_code, res.json)

    async def authenticate_async(
        self,
        user_id: str,
        totp_code: str,
        session_token: Optional[str] = None,
        session_jwt: Optional[str] = None,
        session_duration_minutes: Optional[int] = None,
        session_custom_claims: Optional[Dict[str, Any]] = None,
    ) -> AuthenticateResponse:
        """[Stytch docs](https://stytch.com/docs/api/totp-authenticate)

        Authenticate a TOTP code entered by a user.
        """  # noqa

        payload: Dict[str, Any] = {
            "user_id": user_id,
            "totp_code": totp_code,
        }

        if session_token is not None:
            payload["session_token"] = session_token
        if session_jwt is not None:
            payload["session_jwt"] = session_jwt
        if session_duration_minutes is not None:
            payload["session_duration_minutes"] = session_duration_minutes
        if session_custom_claims is not None:
            payload["session_custom_claims"] = session_custom_claims

        url = self.api_base.route_with_sub_url(self.sub_url, "authenticate")

        res = await self.async_client.post(url, json=payload)
        return AuthenticateResponse.from_json(res.response.status, res.json)

    def recovery_codes(
        self,
        user_id: str,
    ) -> RecoveryCodesResponse:
        """[Stytch docs](https://stytch.com/docs/api/totp-get-recovery-codes)

        Retrieve the recovery codes for a TOTP instance tied to a user.
        """  # noqa

        payload: Dict[str, Any] = {
            "user_id": user_id,
        }

        url = self.api_base.route_with_sub_url(self.sub_url, "recovery_codes")

        res = self.sync_client.post(url, json=payload)
        return RecoveryCodesResponse.from_json(res.response.status_code, res.json)

    async def recovery_codes_async(
        self,
        user_id: str,
    ) -> RecoveryCodesResponse:
        """[Stytch docs](https://stytch.com/docs/api/totp-get-recovery-codes)

        Retrieve the recovery codes for a TOTP instance tied to a user.
        """  # noqa

        payload: Dict[str, Any] = {
            "user_id": user_id,
        }

        url = self.api_base.route_with_sub_url(self.sub_url, "recovery_codes")

        res = await self.async_client.post(url, json=payload)
        return RecoveryCodesResponse.from_json(res.response.status, res.json)

    def recover(
        self,
        user_id: str,
        recovery_code: str,
        session_token: Optional[str] = None,
        session_jwt: Optional[str] = None,
        session_duration_minutes: Optional[int] = None,
        session_custom_claims: Optional[Dict[str, Any]] = None,
    ) -> RecoverResponse:
        """[Stytch docs](https://stytch.com/docs/api/totp-recover)

        Authenticate a recovery code for a TOTP instance.
        """  # noqa

        payload: Dict[str, Any] = {
            "user_id": user_id,
            "recovery_code": recovery_code,
        }

        if session_token is not None:
            payload["session_token"] = session_token
        if session_jwt is not None:
            payload["session_jwt"] = session_jwt
        if session_duration_minutes is not None:
            payload["session_duration_minutes"] = session_duration_minutes
        if session_custom_claims is not None:
            payload["session_custom_claims"] = session_custom_claims

        url = self.api_base.route_with_sub_url(self.sub_url, "recover")

        res = self.sync_client.post(url, json=payload)
        return RecoverResponse.from_json(res.response.status_code, res.json)

    async def recover_async(
        self,
        user_id: str,
        recovery_code: str,
        session_token: Optional[str] = None,
        session_jwt: Optional[str] = None,
        session_duration_minutes: Optional[int] = None,
        session_custom_claims: Optional[Dict[str, Any]] = None,
    ) -> RecoverResponse:
        """[Stytch docs](https://stytch.com/docs/api/totp-recover)

        Authenticate a recovery code for a TOTP instance.
        """  # noqa

        payload: Dict[str, Any] = {
            "user_id": user_id,
            "recovery_code": recovery_code,
        }

        if session_token is not None:
            payload["session_token"] = session_token
        if session_jwt is not None:
            payload["session_jwt"] = session_jwt
        if session_duration_minutes is not None:
            payload["session_duration_minutes"] = session_duration_minutes
        if session_custom_claims is not None:
            payload["session_custom_claims"] = session_custom_claims

        url = self.api_base.route_with_sub_url(self.sub_url, "recover")

        res = await self.async_client.post(url, json=payload)
        return RecoverResponse.from_json(res.response.status, res.json)



#!/usr/bin/env python3

from typing import Optional

from stytch.core.models import ResponseBase, StytchSession, User


class RegisterStartResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/webauthn-register-start)"""  # noqa

    user_id: str
    public_key_credential_creation_options: str


class RegisterResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/webauthn-register)"""  # noqa

    user_id: str
    webauthn_registration_id: str


class AuthenticateStartResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/webauthn-authenticate-start)"""  # noqa

    user_id: str
    public_key_credential_request_options: str


class AuthenticateResponse(ResponseBase):
    """[Stytch docs](https://stytch.com/docs/api/webauthn-authenticate)"""  # noqa

    user_id: str
    user: User
    webauthn_registration_id: str
    session_jwt: str
    session_token: str
    session: Optional[StytchSession]
